Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/common/lib/libc/string Use __register_t instead of uregister...



details:   https://anonhg.NetBSD.org/src/rev/9724f608e392
branches:  trunk
changeset: 961363:9724f608e392
user:      simonb <simonb%NetBSD.org@localhost>
date:      Sat Apr 17 08:06:58 2021 +0000

description:
Use __register_t instead of uregister_t - this is available to all ports
and both userland and kernel.

diffstat:

 common/lib/libc/string/memset2.c |  8 +++-----
 1 files changed, 3 insertions(+), 5 deletions(-)

diffs (26 lines):

diff -r 220250e4ec5f -r 9724f608e392 common/lib/libc/string/memset2.c
--- a/common/lib/libc/string/memset2.c  Sat Apr 17 06:14:15 2021 +0000
+++ b/common/lib/libc/string/memset2.c  Sat Apr 17 08:06:58 2021 +0000
@@ -29,7 +29,7 @@
 
 #include <sys/cdefs.h>
 #if defined(LIBC_SCCS) && !defined(lint)
-__RCSID("$NetBSD: memset2.c,v 1.7 2021/04/17 06:02:35 simonb Exp $");
+__RCSID("$NetBSD: memset2.c,v 1.8 2021/04/17 08:06:58 simonb Exp $");
 #endif /* LIBC_SCCS and not lint */
 
 #include <sys/types.h>
@@ -60,11 +60,9 @@
 #undef memset
 
 /*
  * Assume uregister_t is the widest non-synthetic unsigned type.
  */
-typedef uregister_t memword_t;
-
-__CTASSERT((~(memword_t)0U >> 1) != ~(memword_t)0U);
+typedef __register_t memword_t;
 
 #ifdef BZERO
 static inline
@@ -60,11 +60,9 @@
 
 /*
- * Assume uregister_t is the widest non-synthetic unsigned type.
+ * Assume __register_t is the widest non-synthetic unsigned type.
  */



Home | Main Index | Thread Index | Old Index